# This Python file uses the following encoding: utf-8

# if__name__ == "__main__":
#     pass

import os
import re
import time
import getpass

def get_file_logs(filename, logs=[]):
    """读取auth.log文件，获取域用户登录失败的记录
    args:
        filename - 日志文件路径，一般为/var/log/auth.log
        logs - 已经读取的记录，会与filename中的记录合并
    return:
        包含失败记录的列表
    """
    now = time.localtime()
    with open(filename, "r") as f:
        for line in f:
            if "pam_sss" not in line:
                continue
            dt = line[0:15]
            dt_wy = "%s %s" % (now.tm_year, dt)
            #dt_wy = "%s %s" % ("2022", dt)
            stru_t = time.strptime(dt_wy, "%Y %b %d %H:%M:%S")
            if(stru_t > now):
                dt_wy = "%s %s" % (now.tm_year-1, dt)
                stru_t = time.strptime(dt_wy, "%Y %b %d %H:%M:%S")
            str_time = time.strftime("%Y-%m-%d %H:%M:%S",stru_t);
            if ":account" in line and "Access denied" in line:
                #print(line)
                info = line.split("for user ")[1]
                user = info.split(":")[0]
                code = info.split(" ")[1]
                if code == "6":
                    log = {'name': user, 'msg': '拒绝访问', 'datetime': str_time}
                    logs.append(log)
            if ":auth" in line and "received for user" in line:
                info = line.split("for user ")[1]
                user = info.split(":")[0]
                code = info.split(" ")[1]
                if code == "6":
                    log = {'name': user, 'msg': '账号被禁用或锁定', 'datetime': str_time}
                    logs.append(log)
    return logs

def get_faild_logins():
    """获取两周内的域用户失败登录审计日志，调取服务应当为root或者在adm组中
    return:
        登录失败记录列表
    """
    logs = []
    get_file_logs('/var/log/auth.log', logs)
    get_file_logs('/var/log/auth.log.1', logs)
    return logs

def check_domain_installed():
    return os.path.exists('/var/lib/ipa-client/sysrestore/sysrestore.index')

def is_user_local(username):
    with open('/etc/passwd', 'r') as f:
        for line in f:
            lu = line.split(':')[0]
            if lu == username:
                return True
    return False

def is_online():
    """获取当前用户在线状态，必须以当前用户身份调用
    return:
        在线返回True，离线返回False
    """
    user = getpass.getuser()
    f = os.popen('klist -A')
    bfound = False
    for line in f.readlines():
        if bfound:
            if 'krbtgt' in line:
                dt = line.split(' ')[0]
                if '1970-01-01' not in dt:
                    return True
                else:
                    return False
        if user in line.lower():
            bfound = True
    return False

